@@ -1,3 +1,6 @@
 """Easily find and query AST elements by using CSS Selector-like syntax"""
 
-__version__ = "0.1.0"
+from .main import AstSelector
+
+__version__ = "0.1.1"
+__all__ = ["AstSelector"]
